@@ -42,10 +42,19 @@ __version__ = _cluster.version()
 
 
 class Node(_cluster.Node):
+    """Element of a hierarchical clustering tree.
+
+    A node contains items or other Nodes(sub-nodes).
+    """
+
     __doc__ = _cluster.Node.__doc__
 
 
 class Tree(_cluster.Tree):
+    """Hierarchical clustering tree.
+
+    A Tree consists of Nodes.
+    """
 
     def sort(self, order=None):
         """Sort the hierarchical clustering tree.
@@ -174,19 +183,18 @@ def kmedoids(distance, nclusters=2, npass=1, initialid=None):
 
        Examples are:
 
-           >>> # option 1.:
+           >>> from numpy import array
+           >>> # option 1:
            >>> distance = array([[0.0, 1.1, 2.3],
            ...                   [1.1, 0.0, 4.5],
            ...                   [2.3, 4.5, 0.0]])
-           ...
-           >>> # option 2.:
+           >>> # option 2:
            >>> distance = array([1.1, 2.3, 4.5])
-           >>> # option 3.:
+           >>> # option 3:
            >>> distance = [array([]),
            ...             array([1.1]),
            ...             array([2.3, 4.5])]
-           ...
-           >>>
+
 
        These three correspond to the same distance matrix.
      - nclusters: number of clusters (the 'k' in k-medoids)
@@ -258,19 +266,17 @@ def treecluster(data, mask=None, weight=None, transpose=False, method='m',
 
        Examples are:
 
-           >>> # option 1.:
+           >>> from numpy import array
+           >>> # option 1:
            >>> distance = array([[0.0, 1.1, 2.3],
            ...                   [1.1, 0.0, 4.5],
            ...                   [2.3, 4.5, 0.0]])
-           ...
-           >>> # option 2.:
+           >>> # option 2:
            >>> distance = array([1.1, 2.3, 4.5])
-           >>> # option 3.:
+           >>> # option 3:
            >>> distance = [array([]),
            ...             array([1.1]),
            ...             array([2.3, 4.5])]
-           ...
-           >>>
 
        These three correspond to the same distance matrix.
 
@@ -292,13 +298,22 @@ def treecluster(data, mask=None, weight=None, transpose=False, method='m',
     treecluster returns a Tree object describing the hierarchical clustering
     result. See the description of the Tree class for more information.
     """
+    if data is None and distancematrix is None:
+        raise ValueError('use either data or distancematrix')
+    if data is not None and distancematrix is not None:
+        raise ValueError('use either data or distancematrix; do not use both')
     if data is not None:
         data = __check_data(data)
         shape = data.shape
         ndata = shape[0] if transpose else shape[1]
         mask = __check_mask(mask, shape)
         weight = __check_weight(weight, ndata)
-    distancematrix = __check_distancematrix(distancematrix)
+    if distancematrix is not None:
+        distancematrix = __check_distancematrix(distancematrix)
+        if mask is not None:
+            raise ValueError('mask is ignored if distancematrix is used')
+        if weight is not None:
+            raise ValueError('weight is ignored if distancematrix is used')
     tree = Tree()
     _cluster.treecluster(tree, data, mask, weight, transpose, method, dist,
                          distancematrix)
@@ -479,24 +494,40 @@ def distancematrix(data, mask=None, weight=None, transpose=False, dist='e'):
     The distance matrix is returned as a list of 1D arrays containing the
     distance matrix calculated from the data. The number of columns in eac
     row is equal to the row number. Hence, the first row has zero length.
-    An example of the return value is:
+    For example:
 
-        matrix = [[],
-                  array([1.]),
-                  array([7., 3.]),
-                  array([4., 2., 6.])]
+    >>> from numpy import array
+    >>> from Bio.Cluster import distancematrix
+    >>> data = array([[0, 1,  2,  3],
+    ...               [4, 5,  6,  7],
+    ...               [8, 9, 10, 11],
+    ...               [1, 2,  3,  4]])
+    >>> distances = distancematrix(data, dist='e')
+    >>> distances
+    [array([], dtype=float64), array([ 16.]), array([ 64.,  16.]), array([  1.,   9.,  49.])]
+
+    which can be rewritten as
+       distances = [array([], dtype=float64),
+                    array([ 16.]),
+                    array([ 64.,  16.]),
+                    array([  1.,   9.,  49.])]
 
     This corresponds to the distance matrix:
 
-        [0., 1., 7., 4.]
-        [1., 0., 3., 2.]
-        [7., 3., 0., 6.]
-        [4., 2., 6., 0.]
+        [ 0., 16., 64.,  1.]
+        [16.,  0., 16.,  9.]
+        [64., 16.,  0., 49.]
+        [ 1.,  9., 49.,  0.]
     """
     data = __check_data(data)
-    mask = __check_mask(mask, data.shape)
-    n = data.shape[1] if transpose else data.shape[0]
-    matrix = [numpy.empty(i, dtype='d') for i in range(n)]
+    shape = data.shape
+    mask = __check_mask(mask, shape)
+    if transpose:
+        ndata, nitems = shape
+    else:
+        nitems, ndata = shape
+    weight = __check_weight(weight, ndata)
+    matrix = [numpy.empty(i, dtype='d') for i in range(nitems)]
     _cluster.distancematrix(data, mask, weight, transpose, dist, matrix)
     return matrix
 
@@ -516,11 +547,19 @@ def pca(data):
     eigenvalue, with the largest eigenvalues appearing first. Here, nmin is
     the smaller of nrows and ncolumns.
     Adding the column means to the dot product of the coordinates and the
-    principal components,
+    principal components recreates the data matrix:
 
-    >>> columnmean + dot(coordinates, pc)
+    >>> from numpy import array, dot, amax, amin
+    >>> from Bio.Cluster import pca
+    >>> matrix = array([[ 0.,  0.,  0.],
+    ...                 [ 1.,  0.,  0.],
+    ...                 [ 7.,  3.,  0.],
+    ...                 [ 4.,  2.,  6.]])
+    >>> columnmean, coordinates, pc, _ = pca(matrix)
+    >>> m = matrix - (columnmean + dot(coordinates, pc))
+    >>> amax(m) < 1e-12 and amin(m) > -1e-12
+    True
 
-    recreates the data matrix.
     """
     data = __check_data(data)
     nrows, ncols = data.shape
