@@ -1,10 +1,10 @@
 # Copyright 1999 by Jeffrey Chang.  All rights reserved.
-# Copyright 2009-2015 by Peter Cock. All rights reserved.
+# Copyright 2009-2018 by Peter Cock. All rights reserved.
 #
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
-
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """Code for more fancy file handles.
 
 Classes:
@@ -22,6 +22,7 @@ import os
 import sys
 import contextlib
 import itertools
+import platform
 
 from Bio._py3k import basestring
 
@@ -30,6 +31,17 @@ try:
 except ImportError:
     from UserDict import DictMixin as _dict_base
 
+# Ordered dict is a language feature from Python 3.7 onwards.
+# CPython 3.6 also already has ordered dicts.
+# PyPy has always had ordered dicts.
+if (sys.version_info >= (3, 7)
+        or platform.python_implementation() == "PyPy"
+        or (sys.version_info == (3, 6)
+            and platform.python_implementation() == "CPython")):
+    _dict = dict
+else:
+    from collections import OrderedDict as _dict
+
 try:
     from sqlite3 import dbapi2 as _sqlite
     from sqlite3 import IntegrityError as _IntegrityError
@@ -46,29 +58,38 @@ except ImportError:
 def as_handle(handleish, mode='r', **kwargs):
     r"""Context manager to ensure we are using a handle.
 
-    Context manager for arguments that can be passed to
-    SeqIO and AlignIO read, write, and parse methods: either file objects or strings.
+    Context manager for arguments that can be passed to SeqIO and AlignIO read, write,
+    and parse methods: either file objects or path-like objects (strings, pathlib.Path
+    instances, or more generally, anything that can be handled by the builtin 'open'
+    function).
 
-    When given a string, returns a file handle open to handleish with provided
-    mode which will be closed when the manager exits.
+    When given a path-like object, returns an open file handle to that path, with provided
+    mode, which will be closed when the manager exits.
 
     All other inputs are returned, and are *not* closed.
 
     Arguments:
-     - handleish  - Either a string or file handle
+     - handleish  - Either a file handle or path-like object (anything which can be
+                    passed to the builtin 'open' function: str, bytes, and under
+                    Python >= 3.6, pathlib.Path, os.DirEntry)
      - mode       - Mode to open handleish (used only if handleish is a string)
      - kwargs     - Further arguments to pass to open(...)
 
-    Example:
-
-    >>> with as_handle('seqs.fasta', 'w') as fp:
-    ...     fp.write('>test\nACGT')
+    Examples
+    --------
+    >>> from Bio import File
+    >>> with File.as_handle('seqs.fasta', 'w') as fp:
+    ...     # Python2/3 docstring workaround, revise for 'Python 3 only'.
+    ...     _ = fp.write('>test\nACGT')
+    ...
     >>> fp.closed
     True
 
     >>> handle = open('seqs.fasta', 'w')
-    >>> with as_handle(handle) as fp:
-    ...     fp.write('>test\nACGT')
+    >>> with File.as_handle(handle) as fp:
+    ...     # Python 2/3 docstring workaround, revise for 'Python 3 only'.
+    ...     _ = fp.write('>test\nACGT')
+    ...
     >>> fp.closed
     False
     >>> fp.close()
@@ -76,7 +97,17 @@ def as_handle(handleish, mode='r', **kwargs):
     Note that if the mode argument includes U (for universal new lines)
     this will be removed under Python 3 where is is redundant and has
     been deprecated (this happens automatically in text mode).
+
     """
+    # If we're running under a version of Python that supports PEP 519, try
+    # to convert 'handleish' to a string with 'os.fspath'.
+    if hasattr(os, 'fspath'):
+        try:
+            handleish = os.fspath(handleish)
+        except TypeError:
+            # handleish isn't path-like, and it remains unchanged -- we'll yield it below
+            pass
+
     if isinstance(handleish, basestring):
         if sys.version_info[0] >= 3 and "U" in mode:
             mode = mode.replace("U", "")
@@ -95,15 +126,26 @@ def _open_for_random_access(filename):
 
     This functionality is used by the Bio.SeqIO and Bio.SearchIO index
     and index_db functions.
+
+    If the file is gzipped but not BGZF, a specific ValueError is raised.
     """
     handle = open(filename, "rb")
-    from . import bgzf
-    try:
-        return bgzf.BgzfReader(mode="rb", fileobj=handle)
-    except ValueError as e:
-        assert "BGZF" in str(e)
-        # Not a BGZF file after all, rewind to start:
-        handle.seek(0)
+    magic = handle.read(2)
+    handle.seek(0)
+
+    if magic == b"\x1f\x8b":
+        # This is a gzipped file, but is it BGZF?
+        from . import bgzf
+        try:
+            # If it is BGZF, we support that
+            return bgzf.BgzfReader(mode="rb", fileobj=handle)
+        except ValueError as e:
+            assert "BGZF" in str(e)
+            # Not a BGZF file after all,
+            handle.close()
+            raise ValueError("Gzipped files are not suitable for indexing, "
+                             "please use BGZF (blocked gzip format) instead.")
+
     return handle
 
 
@@ -290,7 +332,7 @@ class _IndexedSeqFileDict(_dict_base):
                 (key_function(k), o, l) for (k, o, l) in random_access_proxy)
         else:
             offset_iter = random_access_proxy
-        offsets = {}
+        offsets = _dict()
         for key, offset, length in offset_iter:
             # Note - we don't store the length because I want to minimise the
             # memory requirements. With the SQLite backend the length is kept
@@ -544,8 +586,12 @@ class _SQLiteManySeqFilesDict(_IndexedSeqFileDict):
             if self._length == -1:
                 con.close()
                 raise ValueError("Unfinished/partial database")
+
+            # use MAX(_ROWID_) to obtain the number of sequences in the database
+            # using COUNT(key) is quite slow in SQLITE
+            # (https://stackoverflow.com/questions/8988915/sqlite-count-slow-on-big-tables)
             count, = con.execute(
-                "SELECT COUNT(key) FROM offset_data;").fetchone()
+                "SELECT MAX(_ROWID_) FROM offset_data;").fetchone()
             if self._length != int(count):
                 con.close()
                 raise ValueError("Corrupt database? %i entries not %i"
@@ -720,7 +766,7 @@ class _SQLiteManySeqFilesDict(_IndexedSeqFileDict):
 
     def __iter__(self):
         """Iterate over the keys."""
-        for row in self._con.execute("SELECT key FROM offset_data;"):
+        for row in self._con.execute("SELECT key FROM offset_data ORDER BY file_number, offset;"):
             yield str(row[0])
 
     if hasattr(dict, "iteritems"):
