@@ -21,16 +21,14 @@ def _gen_random_array(n):
     """Return an array of n random numbers summing to 1.0 (PRIVATE)."""
     randArray = [random.random() for i in range(n)]
     total = sum(randArray)
-    normalizedRandArray = [x / total for x in randArray]
-
-    return normalizedRandArray
+    return [x / total for x in randArray]
 
 
 def _calculate_emissions(emission_probs):
     """Calculate which symbols can be emitted in each state (PRIVATE)."""
     # loop over all of the state-symbol duples, mapping states to
     # lists of emitted symbols
-    emissions = dict()
+    emissions = {}
     for state, symbol in emission_probs:
         try:
             emissions[state].append(symbol)
@@ -49,7 +47,7 @@ def _calculate_from_transitions(trans_probs):
     lists of destination states reachable from the source state via a
     transition.
     """
-    transitions = dict()
+    transitions = {}
     for from_state, to_state in trans_probs:
         try:
             transitions[from_state].append(to_state)
@@ -68,7 +66,7 @@ def _calculate_to_transitions(trans_probs):
     lists of source states from which the destination is reachable via a
     transition.
     """
-    transitions = dict()
+    transitions = {}
     for from_state, to_state in trans_probs:
         try:
             transitions[to_state].append(from_state)
@@ -194,8 +192,9 @@ class MarkovModelBuilder(object):
 
         # ensure that all referenced states are valid
         for state in initial_prob:
-            assert state in self._state_alphabet.letters, \
-                   "State %s was not found in the sequence alphabet" % state
+            if state not in self._state_alphabet.letters:
+                raise ValueError("State %s was not found in the sequence "
+                                 "alphabet" % state)
 
         # distribute the residual probability, if any
         num_states_not_set =\
@@ -344,8 +343,9 @@ class MarkovModelBuilder(object):
         """
         # check the sanity of adding these states
         for state in [from_state, to_state]:
-            assert state in self._state_alphabet.letters, \
-                   "State %s was not found in the sequence alphabet" % state
+            if state not in self._state_alphabet.letters:
+                raise ValueError("State %s was not found in the sequence "
+                                 "alphabet" % state)
 
         # ensure that the states are not already set
         if (from_state, to_state) not in self.transition_prob and \
