@@ -283,9 +283,13 @@ class Entity(object):
 
         Examples
         --------
-        >>> rotation = rotmat(pi, Vector(1, 0, 0))
-        >>> translation = array((0, 0, 1), 'f')
-        >>> entity.transform(rotation, translation)
+        This is an incomplete but illustrative example::
+
+            from numpy import pi, array
+            from Bio.PDB.vectors import Vector, rotmat
+            rotation = rotmat(pi, Vector(1, 0, 0))
+            translation = array((0, 0, 1), 'f')
+            entity.transform(rotation, translation)
 
         """
         for o in self.get_list():
