@@ -8,7 +8,6 @@
 All object representations for phylogenetic trees should derive from these base
 classes in order to use the common methods defined on them.
 """
-__docformat__ = "restructuredtext en"
 
 from Bio._py3k import basestring, filter, unicode, zip
 
@@ -20,12 +19,12 @@ import re
 
 from Bio import _utils
 
-
 # NB: On Python 2, repr() and str() are specified to return byte strings, not
 # unicode. On Python 3, it's the opposite. Horrible.
 import sys
 if sys.version_info[0] < 3:
     def as_string(s):
+        """Encode string to UTF-8."""
         if isinstance(s, unicode):
             return s.encode('utf-8')
         return str(s)
@@ -36,7 +35,7 @@ else:
 # General tree-traversal algorithms
 
 def _level_traverse(root, get_children):
-    """Traverse a tree in breadth-first (level) order."""
+    """Traverse a tree in breadth-first (level) order (PRIVATE)."""
     Q = collections.deque([root])
     while Q:
         v = Q.popleft()
@@ -45,7 +44,7 @@ def _level_traverse(root, get_children):
 
 
 def _preorder_traverse(root, get_children):
-    """Traverse a tree in depth-first pre-order (parent before children)."""
+    """Traverse a tree in depth-first pre-order (parent before children) (PRIVATE)."""
     def dfs(elem):
         yield elem
         for v in get_children(elem):
@@ -56,7 +55,7 @@ def _preorder_traverse(root, get_children):
 
 
 def _postorder_traverse(root, get_children):
-    """Traverse a tree in depth-first post-order (children before parent)."""
+    """Traverse a tree in depth-first post-order (children before parent) (PRIVATE)."""
     def dfs(elem):
         for v in get_children(elem):
             for u in dfs(v):
@@ -67,7 +66,7 @@ def _postorder_traverse(root, get_children):
 
 
 def _sorted_attrs(elem):
-    """Get a flat list of elem's attributes, sorted for consistency."""
+    """Get a flat list of elem's attributes, sorted for consistency (PRIVATE)."""
     singles = []
     lists = []
     # Sort attributes for consistent results
@@ -86,14 +85,14 @@ def _sorted_attrs(elem):
 # Factory functions to generalize searching for clades/nodes
 
 def _identity_matcher(target):
-    """Match a node to the target object by identity."""
+    """Match a node to the target object by identity (PRIVATE)."""
     def match(node):
         return (node is target)
     return match
 
 
 def _class_matcher(target_cls):
-    """Match a node if it's an instance of the given class."""
+    """Match a node if it's an instance of the given class (PRIVATE)."""
     def match(node):
         return isinstance(node, target_cls)
     return match
@@ -109,14 +108,14 @@ def _string_matcher(target):
 
 
 def _attribute_matcher(kwargs):
-    """Match a node by specified attribute values.
+    """Match a node by specified attribute values (PRIVATE).
 
     ``terminal`` is a special case: True restricts the search to external (leaf)
     nodes, False restricts to internal nodes, and None allows all tree elements
     to be searched, including phyloXML annotations.
 
     Otherwise, for a tree element to match the specification (i.e. for the
-    function produced by `_attribute_matcher` to return True when given a tree
+    function produced by ``_attribute_matcher`` to return True when given a tree
     element), it must have each of the attributes specified by the keys and
     match each of the corresponding values -- think 'and', not 'or', for
     multiple keys.
@@ -152,7 +151,7 @@ def _attribute_matcher(kwargs):
 
 
 def _function_matcher(matcher_func):
-    """Safer attribute lookup -- returns False instead of raising an error."""
+    """Safer attribute lookup -- returns False instead of raising an error (PRIVATE)."""
     def match(node):
         try:
             return matcher_func(node)
@@ -162,10 +161,10 @@ def _function_matcher(matcher_func):
 
 
 def _object_matcher(obj):
-    """Retrieve a matcher function by passing an arbitrary object.
+    """Retrieve a matcher function by passing an arbitrary object (PRIVATE).
 
-    i.e. passing a `TreeElement` such as a `Clade` or `Tree` instance returns an
-    identity matcher, passing a type such as the `PhyloXML.Taxonomy` class
+    Passing a ``TreeElement`` such as a ``Clade`` or ``Tree`` instance returns
+    an identity matcher, passing a type such as the ``PhyloXML.Taxonomy`` class
     returns a class matcher, and passing a dictionary returns an attribute
     matcher.
 
@@ -189,7 +188,7 @@ def _object_matcher(obj):
 
 
 def _combine_matchers(target, kwargs, require_spec):
-    """Merge target specifications with keyword arguments.
+    """Merge target specifications with keyword arguments (PRIVATE).
 
     Dispatch the components to the various matcher functions, then merge into a
     single boolean function.
@@ -209,10 +208,10 @@ def _combine_matchers(target, kwargs, require_spec):
 
 
 def _combine_args(first, *rest):
-    """Convert ``[targets]`` or ``*targets`` arguments to a single iterable.
+    """Convert ``[targets]`` or ``*targets`` arguments to a single iterable (PRIVATE).
 
-    This helps other functions work like the built-in functions `max` and
-    `min`.
+    This helps other functions work like the built-in functions ``max`` and
+    ``min``.
     """
     # Background: is_monophyletic takes a single list or iterable (like the
     # same method in Bio.Nexus.Trees); root_with_outgroup and common_ancestor
@@ -224,13 +223,13 @@ def _combine_args(first, *rest):
                                            isinstance(first, type) or
                                            isinstance(first, basestring) or
                                            isinstance(first, dict)):
-        # `terminals` is an iterable of targets
+        # terminals is an iterable of targets
         if rest:
             raise ValueError("Arguments must be either a single list of "
                              "targets, or separately specified targets "
                              "(e.g. foo(t1, t2, t3)), but not both.")
         return first
-    # `terminals` is a single target -- wrap in a container
+    # terminals is a single target -- wrap in a container
     return itertools.chain([first], rest)
 
 
@@ -259,17 +258,19 @@ class TreeElement(object):
 class TreeMixin(object):
     """Methods for Tree- and Clade-based classes.
 
-    This lets `Tree` and `Clade` support the same traversal and searching
+    This lets ``Tree`` and ``Clade`` support the same traversal and searching
     operations without requiring Clade to inherit from Tree, so Clade isn't
     required to have all of Tree's attributes -- just ``root`` (a Clade
     instance) and ``is_terminal``.
     """
+
     # Traversal methods
 
     def _filter_search(self, filter_func, order, follow_attrs):
-        """Perform a BFS or DFS traversal through all elements in this tree.
+        """Perform a BFS or DFS traversal through all elements in this tree (PRIVATE).
+
+        :returns: generator of all elements for which ``filter_func`` is True.
 
-        :returns: generator of all elements for which `filter_func` is True.
         """
         order_opts = {'preorder': _preorder_traverse,
                       'postorder': _postorder_traverse,
@@ -279,11 +280,12 @@ class TreeMixin(object):
         except KeyError:
             raise ValueError("Invalid order '%s'; must be one of: %s"
                              % (order, tuple(order_opts)))
+
         if follow_attrs:
             get_children = _sorted_attrs
             root = self
         else:
-            get_children = lambda elem: elem.clades
+            get_children = lambda elem: elem.clades  # noqa: E731
             root = self.root
         return filter(filter_func, order_func(root, get_children))
 
@@ -332,11 +334,10 @@ class TreeMixin(object):
                 search, 'postorder' is DFS with child nodes preceding parents,
                 and 'level' is breadth-first search.
 
-        Example
-        -------
-
-        >>> from Bio.Phylo.IO import PhyloXMIO
-        >>> phx = PhyloXMLIO.read('phyloxml_examples.xml')
+        Examples
+        --------
+        >>> from Bio import Phylo
+        >>> phx = Phylo.PhyloXMLIO.read('PhyloXML/phyloxml_examples.xml')
         >>> matches = phx.phylogenies[5].find_elements(code='OCTVU')
         >>> next(matches)
         Taxonomy(code='OCTVU', scientific_name='Octopus vulgaris')
@@ -356,6 +357,7 @@ class TreeMixin(object):
 
         :returns: an iterable through all matching objects, searching
             depth-first (preorder) by default.
+
         """
         def match_attrs(elem):
             orig_clades = elem.__dict__.pop('clades')
@@ -375,6 +377,7 @@ class TreeMixin(object):
 
         :returns: list of all clade objects along this path, ending with the
             given target, but excluding the root clade.
+
         """
         # Only one path will work -- ignore weights and visits
         path = []
@@ -407,7 +410,7 @@ class TreeMixin(object):
     def trace(self, start, finish):
         """List of all clade object between two targets in this tree.
 
-        Excluding `start`, including `finish`.
+        Excluding ``start``, including ``finish``.
         """
         mrca = self.common_ancestor(start, finish)
         fromstart = mrca.get_path(start)[-2::-1]
@@ -420,9 +423,10 @@ class TreeMixin(object):
         """Most recent common ancestor (clade) of all the given targets.
 
         Edge cases:
-        - If no target is given, returns self.root
-        - If 1 target is given, returns the target
-        - If any target is not found in this tree, raises a ValueError
+         - If no target is given, returns self.root
+         - If 1 target is given, returns the target
+         - If any target is not found in this tree, raises a ValueError
+
         """
         paths = [self.get_path(t)
                  for t in _combine_args(targets, *more_targets)]
@@ -443,10 +447,10 @@ class TreeMixin(object):
         return mrca
 
     def count_terminals(self):
-        """Counts the number of terminal (leaf) nodes within this tree."""
+        """Count the number of terminal (leaf) nodes within this tree."""
         return _utils.iterlen(self.find_clades(terminal=True))
 
-    def depths(self, unit_branch_lengths=False):
+    def depths(self, unit_branch_lengths=False):  # noqa: D402
         """Create a mapping of tree clades to depths (by branch length).
 
         :Parameters:
@@ -458,11 +462,12 @@ class TreeMixin(object):
         :returns: dict of {clade: depth}, where keys are all of the Clade
             instances in the tree, and values are the distance from the root to
             each clade (including terminals).
+
         """
         if unit_branch_lengths:
-            depth_of = lambda c: 1
+            depth_of = lambda c: 1  # noqa: E731
         else:
-            depth_of = lambda c: c.branch_length or 0
+            depth_of = lambda c: c.branch_length or 0  # noqa: E731
         depths = {}
 
         def update_depths(node, curr_depth):
@@ -512,7 +517,7 @@ class TreeMixin(object):
 
         The given targets must be terminals of the tree.
 
-        To match both `Bio.Nexus.Trees` and the other multi-target methods in
+        To match both ``Bio.Nexus.Trees`` and the other multi-target methods in
         Bio.Phylo, arguments to this method can be specified either of two ways:
         (i) as a single list of targets, or (ii) separately specified targets,
         e.g. is_monophyletic(t1, t2, t3) -- but not both.
@@ -522,6 +527,7 @@ class TreeMixin(object):
         otherwise.
 
         :returns: common ancestor if terminals are monophyletic, otherwise False.
+
         """
         target_set = set(_combine_args(terminals, *more_terminals))
         current = self.root
@@ -537,7 +543,7 @@ class TreeMixin(object):
                 return False
 
     def is_parent_of(self, target=None, **kwargs):
-        """True if target is a descendent of this tree.
+        """Check if target is a descendent of this tree.
 
         Not required to be a direct descendent.
 
@@ -547,7 +553,7 @@ class TreeMixin(object):
         return self.get_path(target, **kwargs) is not None
 
     def is_preterminal(self):
-        """True if all direct descendents are terminal."""
+        """Check if all direct descendents are terminal."""
         if self.root.is_terminal():
             return False
         for clade in self.root.clades:
@@ -563,9 +569,10 @@ class TreeMixin(object):
     # Tree manipulation methods
 
     def collapse(self, target=None, **kwargs):
-        """Deletes target from the tree, relinking its children to its parent.
+        """Delete target from the tree, relinking its children to its parent.
 
         :returns: the parent clade.
+
         """
         path = self.get_path(target, **kwargs)
         if not path:
@@ -591,8 +598,13 @@ class TreeMixin(object):
         For example, this will safely collapse nodes with poor bootstrap
         support:
 
-            >>> tree.collapse_all(lambda c: c.confidence is not None and
-            ...                   c.confidence < 70)
+            >>> from Bio import Phylo
+            >>> tree = Phylo.read('PhyloXML/apaf.xml', 'phyloxml')
+            >>> print("Total branch length %0.2f" % tree.total_branch_length())
+            Total branch length 20.44
+            >>> tree.collapse_all(lambda c: c.confidence is not None and c.confidence < 70)
+            >>> print("Total branch length %0.2f" % tree.total_branch_length())
+            Total branch length 21.37
 
         This implementation avoids strange side-effects by using level-order
         traversal and testing all clade properties (versus the target
@@ -600,7 +612,13 @@ class TreeMixin(object):
         specification in the original tree, it will be collapsed.  For example,
         if the condition is:
 
+            >>> from Bio import Phylo
+            >>> tree = Phylo.read('PhyloXML/apaf.xml', 'phyloxml')
+            >>> print("Total branch length %0.2f" % tree.total_branch_length())
+            Total branch length 20.44
             >>> tree.collapse_all(lambda c: c.branch_length < 0.1)
+            >>> print("Total branch length %0.2f" % tree.total_branch_length())
+            Total branch length 21.13
 
         Collapsing a clade's parent node adds the parent's branch length to the
         child, so during the execution of collapse_all, a clade's branch_length
@@ -640,6 +658,7 @@ class TreeMixin(object):
         longer be a meaningful value.
 
         :returns: parent clade of the pruned target
+
         """
         if 'terminal' in kwargs and kwargs['terminal']:
             raise ValueError("target must be terminal")
@@ -711,9 +730,11 @@ class Tree(TreeElement, TreeMixin):
             The identifier of the tree, if there is one.
         name : str
             The name of the tree, in essence a label.
+
     """
 
     def __init__(self, root=None, rooted=True, id=None, name=None):
+        """Initialize parameter for phylogenetic tree."""
         self.root = root or Clade()
         self.rooted = rooted
         self.id = id
@@ -723,7 +744,7 @@ class Tree(TreeElement, TreeMixin):
     def from_clade(cls, clade, **kwargs):
         """Create a new Tree object given a clade.
 
-        Keyword arguments are the usual `Tree` constructor parameters.
+        Keyword arguments are the usual ``Tree`` constructor parameters.
         """
         root = copy.deepcopy(clade)
         return cls(root, **kwargs)
@@ -737,6 +758,7 @@ class Tree(TreeElement, TreeMixin):
             strings.
 
         :returns: a tree of the same type as this class.
+
         """
         if isinstance(taxa, int):
             taxa = ['taxon%s' % (i + 1) for i in range(taxa)]
@@ -766,7 +788,7 @@ class Tree(TreeElement, TreeMixin):
 
     @property
     def clade(self):
-        """The first clade in this tree (not itself)."""
+        """Return first clade in this tree (not itself)."""
         return self.root
 
     def as_phyloxml(self, **kwargs):
@@ -786,14 +808,13 @@ class Tree(TreeElement, TreeMixin):
         Operates in-place.
 
         Edge cases:
-
-        - If ``outgroup == self.root``, no change
-        - If outgroup is terminal, create new bifurcating root node with a
-          0-length branch to the outgroup
-        - If outgroup is internal, use the given outgroup node as the new
-          trifurcating root, keeping branches the same
-        - If the original root was bifurcating, drop it from the tree,
-          preserving total branch lengths
+         - If ``outgroup == self.root``, no change
+         - If outgroup is terminal, create new bifurcating root node with a
+           0-length branch to the outgroup
+         - If outgroup is internal, use the given outgroup node as the new
+           trifurcating root, keeping branches the same
+         - If the original root was bifurcating, drop it from the tree,
+           preserving total branch lengths
 
         :param outgroup_branch_length: length of the branch leading to the
             outgroup after rerooting. If not specified (None), then:
@@ -815,9 +836,10 @@ class Tree(TreeElement, TreeMixin):
         # Hideous kludge because Py2.x doesn't allow keyword args after *args
         outgroup_branch_length = kwargs.get('outgroup_branch_length')
         if outgroup_branch_length is not None:
-            assert 0 <= outgroup_branch_length <= prev_blen, \
-                "outgroup_branch_length must be between 0 and the " \
-                "original length of the branch leading to the outgroup."
+            if not (0 <= outgroup_branch_length <= prev_blen):
+                raise ValueError("outgroup_branch_length must be between 0 "
+                                 "and the original length of the branch "
+                                 "leading to the outgroup.")
 
         if outgroup.is_terminal() or outgroup_branch_length is not None:
             # Create a new root with a 0-length branch to the outgroup
@@ -916,7 +938,7 @@ class Tree(TreeElement, TreeMixin):
     # Method assumed by TreeMixin
 
     def is_terminal(self):
-        """True if the root of this tree is terminal."""
+        """Check if the root of this tree is terminal."""
         return (not self.root.clades)
 
     # Convention from SeqRecord and Alignment classes
@@ -927,8 +949,9 @@ class Tree(TreeElement, TreeMixin):
         This method supports the ``format`` built-in function added in Python
         2.6/3.0.
 
-        :param format_spec: a lower-case string supported by `Bio.Phylo.write`
+        :param format_spec: a lower-case string supported by ``Bio.Phylo.write``
             as an output file format.
+
         """
         if format_spec:
             from Bio._py3k import StringIO
@@ -950,9 +973,9 @@ class Tree(TreeElement, TreeMixin):
     # Pretty-printer for the entire tree hierarchy
 
     def __str__(self):
-        """String representation of the entire tree.
+        """Return a string representation of the entire tree.
 
-        Serializes each sub-clade recursively using ``repr`` to create a summary
+        Serialize each sub-clade recursively using ``repr`` to create a summary
         of the object structure.
         """
         TAB = '    '
@@ -999,10 +1022,12 @@ class Clade(TreeElement, TreeMixin):
             The display color of the branch and descendents.
         width : number
             The display width of the branch and descendents.
+
     """
 
     def __init__(self, branch_length=None, name=None, clades=None,
                  confidence=None, color=None, width=None):
+        """Define parameters for the Clade tree."""
         self.branch_length = branch_length
         self.name = name
         self.clades = clades or []
@@ -1016,14 +1041,14 @@ class Clade(TreeElement, TreeMixin):
         return self
 
     def is_terminal(self):
-        """True if this is a terminal (leaf) node."""
+        """Check if this is a terminal (leaf) node."""
         return (not self.clades)
 
     # Sequence-type behavior methods
 
     def __getitem__(self, index):
         """Get clades by index (integer or slice)."""
-        if isinstance(index, int) or isinstance(index, slice):
+        if isinstance(index, (int, slice)):
             return self.clades[index]
         ref = self
         for idx in index:
@@ -1035,7 +1060,7 @@ class Clade(TreeElement, TreeMixin):
         return iter(self.clades)
 
     def __len__(self):
-        """Number of clades directy under the root."""
+        """Return the number of clades directy under the root."""
         return len(self.clades)
 
     # Python 3:
@@ -1051,6 +1076,7 @@ class Clade(TreeElement, TreeMixin):
     __nonzero__ = __bool__
 
     def __str__(self):
+        """Return name of the class instance."""
         if self.name:
             return _utils.trim_str(self.name, 40, '...')
         return self.__class__.__name__
@@ -1091,45 +1117,46 @@ class BranchColor(object):
     """
 
     color_names = {
-        'red':     (255,   0,   0),
-        'r':       (255,   0,   0),
-        'yellow':  (255, 255,   0),
-        'y':       (255, 255,   0),
-        'green':   (  0, 128,   0),
-        'g':       (  0, 128,   0),
-        'cyan':    (  0, 255, 255),
-        'c':       (  0, 255, 255),
-        'blue':    (  0,   0, 255),
-        'b':       (  0,   0, 255),
-        'magenta': (255,   0, 255),
-        'm':       (255,   0, 255),
-        'black':   (  0,   0,   0),
-        'k':       (  0,   0,   0),
-        'white':   (255, 255, 255),
-        'w':       (255, 255, 255),
+        'red': (255, 0, 0),
+        'r': (255, 0, 0),
+        'yellow': (255, 255, 0),
+        'y': (255, 255, 0),
+        'green': (0, 128, 0),
+        'g': (0, 128, 0),
+        'cyan': (0, 255, 255),
+        'c': (0, 255, 255),
+        'blue': (0, 0, 255),
+        'b': (0, 0, 255),
+        'magenta': (255, 0, 255),
+        'm': (255, 0, 255),
+        'black': (0, 0, 0),
+        'k': (0, 0, 0),
+        'white': (255, 255, 255),
+        'w': (255, 255, 255),
         # Names standardized in HTML/CSS spec
         # http://w3schools.com/html/html_colornames.asp
-        'maroon':  (128,   0,   0),
-        'olive':   (128, 128,   0),
-        'lime':    (  0, 255,   0),
-        'aqua':    (  0, 255, 255),
-        'teal':    (  0, 128, 128),
-        'navy':    (  0,   0, 128),
-        'fuchsia': (255,   0, 255),
-        'purple':  (128,   0, 128),
-        'silver':  (192, 192, 192),
-        'gray':    (128, 128, 128),
+        'maroon': (128, 0, 0),
+        'olive': (128, 128, 0),
+        'lime': (0, 255, 0),
+        'aqua': (0, 255, 255),
+        'teal': (0, 128, 128),
+        'navy': (0, 0, 128),
+        'fuchsia': (255, 0, 255),
+        'purple': (128, 0, 128),
+        'silver': (192, 192, 192),
+        'gray': (128, 128, 128),
         # More definitions from matplotlib/gcolor2
-        'grey':    (128, 128, 128),
-        'pink':    (255, 192, 203),
-        'salmon':  (250, 128, 114),
-        'orange':  (255, 165,   0),
-        'gold':    (255, 215,   0),
-        'tan':     (210, 180, 140),
-        'brown':   (165,  42,  42),
+        'grey': (128, 128, 128),
+        'pink': (255, 192, 203),
+        'salmon': (250, 128, 114),
+        'orange': (255, 165, 0),
+        'gold': (255, 215, 0),
+        'tan': (210, 180, 140),
+        'brown': (165, 42, 42),
         }
 
     def __init__(self, red, green, blue):
+        """Initialize BranchColor for a tree."""
         for color in (red, green, blue):
             assert (isinstance(color, int) and
                     0 <= color <= 255
@@ -1164,22 +1191,24 @@ class BranchColor(object):
         The returned string is suitable for use in HTML/CSS, as a color
         parameter in matplotlib, and perhaps other situations.
 
-        Example:
+        Examples
+        --------
+        >>> bc = BranchColor(12, 200, 100)
+        >>> bc.to_hex()
+        '#0cc864'
 
-            >>> bc = BranchColor(12, 200, 100)
-            >>> bc.to_hex()
-            '#0cc864'
         """
         return "#%02x%02x%02x" % (self.red, self.green, self.blue)
 
     def to_rgb(self):
         """Return a tuple of RGB values (0 to 255) representing this color.
 
-        Example:
+        Examples
+        --------
+        >>> bc = BranchColor(255, 165, 0)
+        >>> bc.to_rgb()
+        (255, 165, 0)
 
-            >>> bc = BranchColor(255, 165, 0)
-            >>> bc.to_rgb()
-            (255, 165, 0)
         """
         return (self.red, self.green, self.blue)
 
