@@ -1,6 +1,8 @@
-# Copyright Yair Benita Y.Benita@pharm.uu.nl
-# Biopython (http://biopython.org) license applies
-
+# Copyright 2003 Yair Benita.  All rights reserved.
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 """Simple protein analysis.
 
 Example:
@@ -90,7 +92,7 @@ class ProteinAnalysis(object):
         It is not recalculated upon subsequent calls.
         """
         if self.amino_acids_content is None:
-            prot_dic = dict((k, 0) for k in IUPACData.protein_letters)
+            prot_dic = {k: 0 for k in IUPACData.protein_letters}
             for aa in prot_dic:
                 prot_dic[aa] = self.sequence.count(aa)
 
