@@ -112,8 +112,8 @@ class CodonSeq(Seq):
         return Seq(self._data[index], alphabet=generic_dna)
 
     def get_codon(self, index):
-        """Get the `index`-th codon from the sequence."""
-        if len(set(i % 3 for i in self.rf_table)) != 1:
+        """Get the index codon from the sequence."""
+        if len({i % 3 for i in self.rf_table}) != 1:
             raise RuntimeError("frameshift detected. "
                                "CodonSeq object is not able to deal "
                                "with codon sequence with frameshift. "
@@ -195,6 +195,7 @@ class CodonSeq(Seq):
         return "".join(amino_acids)
 
     def toSeq(self, alphabet=generic_dna):
+        """Convert DNA to seq object."""
         return Seq(self._data, generic_dna)
 
     def get_full_rf_table(self):
@@ -244,6 +245,7 @@ class CodonSeq(Seq):
                               rf_table=full_rf_table, ungap_seq=False)
 
     def ungap(self, gap=None):
+        """Return a copy of the sequence without the gap character(s)."""
         if hasattr(self.alphabet, "gap_char"):
             if not gap:
                 gap = self.alphabet.gap_char
@@ -263,6 +265,7 @@ class CodonSeq(Seq):
 
     @classmethod
     def from_seq(cls, seq, alphabet=default_codon_alphabet, rf_table=None):
+        """Get codon sequence from sequence data."""
         if rf_table is None:
             return cls(seq._data, alphabet=alphabet)
         else:
@@ -587,7 +590,7 @@ def _lwl85(seq1, seq2, k, codon_table):
 def _get_codon_fold(codon_table):
     """Classify different position in a codon into different folds (PRIVATE)."""
     def find_fold_class(codon, forward_table):
-        base = set(['A', 'T', 'C', 'G'])
+        base = {'A', 'T', 'C', 'G'}
         fold = ''
         codon_base_lst = [i for i in codon]
         for i, b in enumerate(codon_base_lst):
@@ -631,34 +634,34 @@ def _diff_codon(codon1, codon2, fold_dict):
     purine = ('A', 'G')
     pyrimidine = ('T', 'C')
     for n, (i, j) in enumerate(zip(codon1, codon2)):
-            if i != j and (i in purine and j in purine):
-                if fold_num[n] == '0':
-                    P0 += 1
-                elif fold_num[n] == '2':
-                    P2 += 1
-                elif fold_num[n] == '4':
-                    P4 += 1
-                else:
-                    raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
-            if i != j and (i in pyrimidine and j in pyrimidine):
-                if fold_num[n] == '0':
-                    P0 += 1
-                elif fold_num[n] == '2':
-                    P2 += 1
-                elif fold_num[n] == '4':
-                    P4 += 1
-                else:
-                    raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
-            if i != j and ((i in purine and j in pyrimidine) or
-                           (i in pyrimidine and j in purine)):
-                if fold_num[n] == '0':
-                    Q0 += 1
-                elif fold_num[n] == '2':
-                    Q2 += 1
-                elif fold_num[n] == '4':
-                    Q4 += 1
-                else:
-                    raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
+        if i != j and (i in purine and j in purine):
+            if fold_num[n] == '0':
+                P0 += 1
+            elif fold_num[n] == '2':
+                P2 += 1
+            elif fold_num[n] == '4':
+                P4 += 1
+            else:
+                raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
+        if i != j and (i in pyrimidine and j in pyrimidine):
+            if fold_num[n] == '0':
+                P0 += 1
+            elif fold_num[n] == '2':
+                P2 += 1
+            elif fold_num[n] == '4':
+                P4 += 1
+            else:
+                raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
+        if i != j and ((i in purine and j in pyrimidine) or
+                       (i in pyrimidine and j in purine)):
+            if fold_num[n] == '0':
+                Q0 += 1
+            elif fold_num[n] == '2':
+                Q2 += 1
+            elif fold_num[n] == '4':
+                Q4 += 1
+            else:
+                raise RuntimeError("Unexpected fold_num %d" % fold_num[n])
     return (P0, P2, P4, Q0, Q2, Q4)
 
 
@@ -707,7 +710,7 @@ def _yn00(seq1, seq2, k, codon_table):
     # count synonymous sites and non-synonymous sites
     for i in range(3):
         tot = sum(fcodon[i].values())
-        fcodon[i] = dict((j, k / tot) for j, k in fcodon[i].items())
+        fcodon[i] = {j: k / tot for j, k in fcodon[i].items()}
     pi = defaultdict(int)
     for i in list(codon_table.forward_table.keys()) + codon_table.stop_codons:
         if 'U' not in i:
@@ -1109,7 +1112,7 @@ def _get_pi(seq1, seq2, cmethod, codon_table=default_codon_table):
                 for c in i:
                     fcodon[c] += 1
         tot = sum(fcodon.values())
-        fcodon = dict((j, k / tot) for j, k in fcodon.items())
+        fcodon = {j: k / tot for j, k in fcodon.items()}
         for i in codon_table.forward_table.keys() + codon_table.stop_codons:
             if 'U' not in i:
                 pi[i] = fcodon[i[0]] * fcodon[i[1]] * fcodon[i[2]]
@@ -1125,7 +1128,7 @@ def _get_pi(seq1, seq2, cmethod, codon_table=default_codon_table):
                 fcodon[2][i[2]] += 1
         for i in range(3):
             tot = sum(fcodon[i].values())
-            fcodon[i] = dict((j, k / tot) for j, k in fcodon[i].items())
+            fcodon[i] = {j: k / tot for j, k in fcodon[i].items()}
         for i in list(codon_table.forward_table.keys()) + \
                 codon_table.stop_codons:
             if 'U' not in i:
@@ -1138,7 +1141,7 @@ def _get_pi(seq1, seq2, cmethod, codon_table=default_codon_table):
             if i != '---':
                 pi[i] += 1
         tot = sum(pi.values())
-        pi = dict((j, k / tot) for j, k in pi.items())
+        pi = {j: k / tot for j, k in pi.items()}
     return pi
 
 
