@@ -1,9 +1,11 @@
 # Copyright 2002 by Andrew Dalke.  All rights reserved.
 # Revisions 2007-2016 copyright by Peter Cock.  All rights reserved.
 # Revisions 2008-2009 copyright by Cymon J. Cox.  All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 #
 # Note that BioSQL (including the database schema and scripts) is
 # available and licensed separately.  Please consult www.biosql.org
@@ -135,7 +137,7 @@ class DBSeq(Seq):
         """Add another sequence or string to this sequence.
 
         The sequence is first converted to a Seq object before the addition.
-        The returned object is a Seq object, not a DBSeq object
+        The returned object is a Seq object, not a DBSeq object.
         """
         # Let the Seq object deal with the alphabet issues etc
         return self.toseq() + other
@@ -144,11 +146,38 @@ class DBSeq(Seq):
         """Add another sequence or string to the left.
 
         The sequence is first converted to a Seq object before the addition.
-        The returned object is a Seq object, not a DBSeq object
+        The returned object is a Seq object, not a DBSeq object.
         """
         # Let the Seq object deal with the alphabet issues etc
         return other + self.toseq()
 
+    def __mul__(self, other):
+        """Multiply sequence by an integer.
+
+        The sequence is first converted to a Seq object before multiplication.
+        The returned object is a Seq object, not a DBSeq object.
+        """
+        # Let the Seq object deal with the alphabet issues etc
+        return self.toseq() * other
+
+    def __rmul__(self, other):
+        """Multiply integer by a sequence.
+
+        The sequence is first converted to a Seq object before multiplication.
+        The returned object is a Seq object, not a DBSeq object.
+        """
+        # Let the Seq object deal with the alphabet issues etc
+        return other * self.toseq()
+
+    def __imul__(self, other):
+        """Multiply sequence by integer in-place.
+
+        The sequence is first converted to a Seq object before multiplication.
+        The returned object is a Seq object, not a DBSeq object.
+        """
+        # Let the Seq object deal with the alphabet issues etc
+        return self.toseq() * other
+
 
 def _retrieve_seq_len(adaptor, primary_id):
     # The database schema ensures there will be only one matching row
@@ -217,13 +246,13 @@ def _retrieve_seq(adaptor, primary_id):
 
 
 def _retrieve_dbxrefs(adaptor, primary_id):
-    """Retrieve the database cross references for the sequence."""
+    """Retrieve the database cross references for the sequence (PRIVATE)."""
     _dbxrefs = []
     dbxrefs = adaptor.execute_and_fetchall(
-        "SELECT dbname, accession, version"
-        " FROM bioentry_dbxref join dbxref using (dbxref_id)"
-        " WHERE bioentry_id = %s"
-        " ORDER BY rank", (primary_id,))
+        'SELECT dbname, accession, version'
+        ' FROM bioentry_dbxref join dbxref using (dbxref_id)'
+        ' WHERE bioentry_id = %s'
+        ' ORDER BY "rank"', (primary_id,))
     for dbname, accession, version in dbxrefs:
         if version and version != "0":
             v = "%s.%s" % (accession, version)
@@ -234,37 +263,37 @@ def _retrieve_dbxrefs(adaptor, primary_id):
 
 
 def _retrieve_features(adaptor, primary_id):
-    sql = "SELECT seqfeature_id, type.name, rank" \
-          " FROM seqfeature join term type on (type_term_id = type.term_id)" \
-          " WHERE bioentry_id = %s" \
-          " ORDER BY rank"
+    sql = 'SELECT seqfeature_id, type.name, "rank"' \
+          ' FROM seqfeature join term type on (type_term_id = type.term_id)' \
+          ' WHERE bioentry_id = %s' \
+          ' ORDER BY "rank"'
     results = adaptor.execute_and_fetchall(sql, (primary_id,))
     seq_feature_list = []
     for seqfeature_id, seqfeature_type, seqfeature_rank in results:
         # Get qualifiers [except for db_xref which is stored separately]
         qvs = adaptor.execute_and_fetchall(
-            "SELECT name, value"
-            " FROM seqfeature_qualifier_value  join term using (term_id)"
-            " WHERE seqfeature_id = %s"
-            " ORDER BY rank", (seqfeature_id,))
+            'SELECT name, value'
+            ' FROM seqfeature_qualifier_value  join term using (term_id)'
+            ' WHERE seqfeature_id = %s'
+            ' ORDER BY "rank"', (seqfeature_id,))
         qualifiers = {}
         for qv_name, qv_value in qvs:
             qualifiers.setdefault(qv_name, []).append(qv_value)
         # Get db_xrefs [special case of qualifiers]
         qvs = adaptor.execute_and_fetchall(
-            "SELECT dbxref.dbname, dbxref.accession"
-            " FROM dbxref join seqfeature_dbxref using (dbxref_id)"
-            " WHERE seqfeature_dbxref.seqfeature_id = %s"
-            " ORDER BY rank", (seqfeature_id,))
+            'SELECT dbxref.dbname, dbxref.accession'
+            ' FROM dbxref join seqfeature_dbxref using (dbxref_id)'
+            ' WHERE seqfeature_dbxref.seqfeature_id = %s'
+            ' ORDER BY "rank"', (seqfeature_id,))
         for qv_name, qv_value in qvs:
             value = "%s:%s" % (qv_name, qv_value)
             qualifiers.setdefault("db_xref", []).append(value)
         # Get locations
         results = adaptor.execute_and_fetchall(
-            "SELECT location_id, start_pos, end_pos, strand"
-            " FROM location"
-            " WHERE seqfeature_id = %s"
-            " ORDER BY rank", (seqfeature_id,))
+            'SELECT location_id, start_pos, end_pos, strand'
+            ' FROM location'
+            ' WHERE seqfeature_id = %s'
+            ' ORDER BY "rank"', (seqfeature_id,))
         locations = []
         # convert to Python standard form
         # Convert strand = 0 to strand = None
@@ -340,7 +369,7 @@ def _retrieve_features(adaptor, primary_id):
             # Locations are typically in biological in order (see negative
             # strands below), but because of remote locations for
             # sub-features they are not necessarily in numerical order:
-            strands = set(l.strand for l in locs)
+            strands = {l.strand for l in locs}
             if len(strands) == 1 and -1 in strands:
                 # Evil hack time for backwards compatibility
                 # TODO - Check if BioPerl and (old) Biopython did the same,
@@ -391,10 +420,10 @@ def _make_unicode_into_string(text):
 
 def _retrieve_qualifier_value(adaptor, primary_id):
     qvs = adaptor.execute_and_fetchall(
-        "SELECT name, value"
-        " FROM bioentry_qualifier_value JOIN term USING (term_id)"
-        " WHERE bioentry_id = %s"
-        " ORDER BY rank", (primary_id,))
+        'SELECT name, value'
+        ' FROM bioentry_qualifier_value JOIN term USING (term_id)'
+        ' WHERE bioentry_id = %s'
+        ' ORDER BY "rank"', (primary_id,))
     qualifiers = {}
     for name, value in qvs:
         if name == "keyword":
@@ -412,14 +441,14 @@ def _retrieve_reference(adaptor, primary_id):
     # XXX dbxref_qualifier_value
 
     refs = adaptor.execute_and_fetchall(
-        "SELECT start_pos, end_pos, "
-        " location, title, authors,"
-        " dbname, accession"
-        " FROM bioentry_reference"
-        " JOIN reference USING (reference_id)"
-        " LEFT JOIN dbxref USING (dbxref_id)"
-        " WHERE bioentry_id = %s"
-        " ORDER BY rank", (primary_id,))
+        'SELECT start_pos, end_pos, '
+        ' location, title, authors,'
+        ' dbname, accession'
+        ' FROM bioentry_reference'
+        ' JOIN reference USING (reference_id)'
+        ' LEFT JOIN dbxref USING (dbxref_id)'
+        ' WHERE bioentry_id = %s'
+        ' ORDER BY "rank"', (primary_id,))
     references = []
     for start, end, location, title, authors, dbname, accession in refs:
         reference = SeqFeature.Reference()
@@ -495,9 +524,9 @@ def _retrieve_taxon(adaptor, primary_id, taxon_id):
 
 def _retrieve_comment(adaptor, primary_id):
     qvs = adaptor.execute_and_fetchall(
-        "SELECT comment_text FROM comment"
-        " WHERE bioentry_id=%s"
-        " ORDER BY rank", (primary_id,))
+        'SELECT comment_text FROM comment'
+        ' WHERE bioentry_id=%s'
+        ' ORDER BY "rank"', (primary_id,))
     comments = [comm[0] for comm in qvs]
     # Don't want to add an empty list...
     if comments:
